from models.db import Db


class Orders(Db):
    def __init__(self, db):
        Db.__init__(self, db, 'crm_global', 'orders')
        self.set_constraint('orders_pk', ['crm_id', 'order_id', 'month_date'])

    def delete_crm(self, crm_id):
        self.engine.execute(f"Delete from {self.schema}.{self.table} where crm_id = '{crm_id}'")


class EmployeeNotes(Db):
    def __init__(self, db):
        Db.__init__(self, db, 'crm_global', 'employee_notes')
        self.set_constraint('employee_notes_pk', ['crm_id', 'date_time', 'native_order_id', 'note_index'])

    def delete_crm(self, crm_id):
        self.engine.execute(f"Delete from {self.schema}.{self.table} where crm_id = '{crm_id}'")


class SystemNotes(Db):
    def __init__(self, db):
        Db.__init__(self, db, 'crm_global', 'system_notes')
        self.set_constraint('system_notes_pk', ['crm_id', 'date_time', 'native_order_id', 'note_index'])

    def delete_crm(self, crm_id):
        self.engine.execute(f"Delete from {self.schema}.{self.table} where crm_id = '{crm_id}'")


from models.konn.transactions import Transactions
from models.konn.customers import Customers
from models.konn.orders import Orders
from models.konn.purchases import Purchases
from models.konn.notes import Notes
from models.konn.paysources import PaySources
from models.konn.transaction_items import TransactionItems
from models.konn.fullfillment_items import FulfillmentItems
from models.konn.order_items import OrderItems
from models.konn.gateways import Merchants
from models.konn.campaigns import Campaigns
from models.konn.products import Products
from models.konn.composite import Composite
from models.konn.hybrid import Hybrid
from models.konn.hybrid_notes import *
from models.konn.hybrid_campaigns import HybridCampaigns
from models.konn.kk_struc import KKStruc
